==> hoteldruid-mod-nl_3.0.3-1.tar.gz: nl/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Nieuwe reservering"; break;
case "cognome":  				$messaggio = "achternaam"; break;
case "dal":  					$messaggio = "van"; break;
case "al":  					$messaggio = "tot"; break;
case "Tipo di tariffa":  			$messaggio = "Tarief type"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "sconto":  				$messaggio = "korting"; break;
case "caparra":  				$messaggio = "deposito"; break;
case "se diversa dalla normale":  		$messaggio = "anders dan normaal"; break;
case "nº di persone":  				$messaggio = "aantal personen"; break;
case "Nº di piano":  				$messaggio = "Etage"; break;
case "e/o di casa":  				$messaggio = "en/of huisnummer"; break;
case "e/o di persone":  			$messaggio = "en/of aantal personen"; break;
case "costo aggiuntivo unico":  		$messaggio = "1 persoon extra kosten"; break;
case "da moltiplicare per":  			$messaggio = "vermenigvulden met"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "wekelijks exra kosten"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "dagelijkse extra kosten"; break;
case "nº di settimane da applicare":  		$messaggio = "nº aantal weken toevoegen"; break;
case "nº di giorni da applicare":  		$messaggio = "nº aantal dagen toevoegen"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "Inserisci la prenotazione":  		$messaggio = "Voeg reservering in"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar het hoofdmenu"; break;
case " o spezzarla":  				$messaggio = " of verdeel het"; break;
case "Spezza la prenotazione in":  		$messaggio = "Verdeel de reservering in"; break;
case "parti":  					$messaggio = "delen"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Het was niet mogelijk de reservering op te delen vanwege het aantal mensen"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Het is niet mogelijk de reserfering in te voegen zonder"; break;
case "dividerla":  				$messaggio = "verdeel het"; break;
case "in":  					$messaggio = "in"; break;
case "Spezza la prenotazione in":  		$messaggio = "Verdeel de reservering in"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Het was niet mogelijk de reservering in te voegen voor"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "omdat de database intussen is gewijzigd"; break;
case "Prenotazione":  				$messaggio = "Reservering"; break;
case "giorn":  					$messaggio = "dag"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "voor dhr/mevr"; break;
case "per":  					$messaggio = "voor"; break;
case "persone":  				$messaggio = "mensen"; break;
case "Costo unico":  				$messaggio = "single kosten"; break;
case "moltiplicato per":  			$messaggio = "vermenigvuldigd met"; break;
case "Costo settimanale":  			$messaggio = "Wekelijkse kosten"; break;
case "Costo giornaliero":  			$messaggio = "Dagelijkse kosten"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Caparra":  				$messaggio = "Vooruitbetaling"; break;
case "resto da pagare":  			$messaggio = "te betalen restant"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "inserita":  				$messaggio = "ingevoegd"; break;
case "Modifica la prenotazione":  		$messaggio = "Wijzig reservering"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Sconto":  				$messaggio = "Korting"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "De achternaam van de gast is nodig"; break;
case "confermata":  				$messaggio = "bevestigd"; break;
case "Confermata":  				$messaggio = "Bevestigd"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Aantal reserveringen voor dit type"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Voeg andere types toe"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Er is geen reservering toegevoegd"; break;
case "Transazione scaduta":  			$messaggio = "Transactie verlopen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Het is niet mogelijk extra kosten voor de reservering toe te voegen"; break;
case "Orario stimato di entrata":  		$messaggio = "Verwachte aankomsttijd op"; break;
case "giorno":  				$messaggio = "dag"; break;
case "Metodo pagamento caparra":  		$messaggio = "Deposito betaalmethode"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "De gevraagde reservering in dhet bericht is reeds ingevoegd"; break;
case "Attenzione":  				$messaggio = "Waarschuwing"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "de totale prijs van de ingevoegde reserveringen"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "het totaal bedrasg van ingevoegde depositos"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "is afwijkend van diegenen die in de reserveringsaanvraag staat"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "Cliente titolare":  			$messaggio = "Titular client"; break;
case "nome":  					$messaggio = "name"; break;
case "Dal":  					$messaggio = "From"; break;
case "settiman":  				$messaggio = "week"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Warning</b>: total price"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "is different from remote price"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "valuta":  				$messaggio = "currency"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.tar.gz: nl/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Nieuwe reservering"; break;
case "cognome":  				$messaggio = "achternaam"; break;
case "dal":  					$messaggio = "van"; break;
case "al":  					$messaggio = "tot"; break;
case "Tipo di tariffa":  			$messaggio = "Tarief type"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "sconto":  				$messaggio = "korting"; break;
case "caparra":  				$messaggio = "deposito"; break;
case "se diversa dalla normale":  		$messaggio = "anders dan normaal"; break;
case "nº di persone":  				$messaggio = "aantal personen"; break;
case "Nº di piano":  				$messaggio = "Etage"; break;
case "e/o di casa":  				$messaggio = "en/of huisnummer"; break;
case "e/o di persone":  			$messaggio = "en/of aantal personen"; break;
case "costo aggiuntivo unico":  		$messaggio = "1 persoon extra kosten"; break;
case "da moltiplicare per":  			$messaggio = "vermenigvulden met"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "wekelijks exra kosten"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "dagelijkse extra kosten"; break;
case "nº di settimane da applicare":  		$messaggio = "nº aantal weken toevoegen"; break;
case "nº di giorni da applicare":  		$messaggio = "nº aantal dagen toevoegen"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "Inserisci la prenotazione":  		$messaggio = "Voeg reservering in"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar het hoofdmenu"; break;
case " o spezzarla":  				$messaggio = " of verdeel het"; break;
case "Spezza la prenotazione in":  		$messaggio = "Verdeel de reservering in"; break;
case "parti":  					$messaggio = "delen"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Het was niet mogelijk de reservering op te delen vanwege het aantal mensen"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Het is niet mogelijk de reserfering in te voegen zonder"; break;
case "dividerla":  				$messaggio = "verdeel het"; break;
case "in":  					$messaggio = "in"; break;
case "Spezza la prenotazione in":  		$messaggio = "Verdeel de reservering in"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Het was niet mogelijk de reservering in te voegen voor"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "omdat de database intussen is gewijzigd"; break;
case "Prenotazione":  				$messaggio = "Reservering"; break;
case "giorn":  					$messaggio = "dag"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "voor dhr/mevr"; break;
case "per":  					$messaggio = "voor"; break;
case "persone":  				$messaggio = "mensen"; break;
case "Costo unico":  				$messaggio = "single kosten"; break;
case "moltiplicato per":  			$messaggio = "vermenigvuldigd met"; break;
case "Costo settimanale":  			$messaggio = "Wekelijkse kosten"; break;
case "Costo giornaliero":  			$messaggio = "Dagelijkse kosten"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Caparra":  				$messaggio = "Vooruitbetaling"; break;
case "resto da pagare":  			$messaggio = "te betalen restant"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "inserita":  				$messaggio = "ingevoegd"; break;
case "Modifica la prenotazione":  		$messaggio = "Wijzig reservering"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Sconto":  				$messaggio = "Korting"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "De achternaam van de gast is nodig"; break;
case "confermata":  				$messaggio = "bevestigd"; break;
case "Confermata":  				$messaggio = "Bevestigd"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Aantal reserveringen voor dit type"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Voeg andere types toe"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Er is geen reservering toegevoegd"; break;
case "Transazione scaduta":  			$messaggio = "Transactie verlopen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Het is niet mogelijk extra kosten voor de reservering toe te voegen"; break;
case "Orario stimato di entrata":  		$messaggio = "Verwachte aankomsttijd op"; break;
case "giorno":  				$messaggio = "dag"; break;
case "Metodo pagamento caparra":  		$messaggio = "Deposito betaalmethode"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "De gevraagde reservering in dhet bericht is reeds ingevoegd"; break;
case "Attenzione":  				$messaggio = "Waarschuwing"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "de totale prijs van de ingevoegde reserveringen"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "het totaal bedrasg van ingevoegde depositos"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "is afwijkend van diegenen die in de reserveringsaanvraag staat"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "Cliente titolare":  			$messaggio = "Titular client"; break;
case "nome":  					$messaggio = "name"; break;
case "Dal":  					$messaggio = "From"; break;
case "settiman":  				$messaggio = "week"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Warning</b>: total price"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "is different from remote price"; break;
case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "valuta":  				$messaggio = "currency"; break;
case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
case "da":  					$messaggio = "from"; break;
case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
